@@ -9,15 +9,12 @@ from pathlib import Path
 
 import freephil
 
-# import nexgen.phil
 from nexgen import get_filename_template
 from nexgen.nxs_write.NexusWriter import write_new_nexus
 
 # from .. import get_filename_template
 # from ..nxs_write.NexusWriter import write_new_nexus
 
-# import writer
-
 logger = logging.getLogger("NeXusWriter")
 
 master_phil = freephil.parse(
@@ -50,11 +47,13 @@ master_phil = freephil.parse(
         .help = "If True, create also a _vds.h5 file. Only for image data."
     }
 
-    include scope nexgen.nxs_phil.goniometer_scope
+    include scope nexgen.command_line.nxs_phil.goniometer_scope
 
-    include scope nexgen.nxs_phil.beamline_scope
+    include scope nexgen.command_line.nxs_phil.beamline_scope
 
-    include scope nexgen.nxs_phil.detector_scope
+    include scope nexgen.command_line.nxs_phil.detector_scope
+
+    include scope nexgen.command_line.nxs_phil.module_scope
     """,
     process_includes=True,
 )
@@ -125,7 +124,7 @@ def main():
     cf = params.input.coordinate_frame
     goniometer = params.goniometer
     detector = params.detector
-    module = params.module
+    module = params.detector_module
     source = params.source
     beam = params.beam
     attenuator = params.attenuator
