@@ -1,11 +1,10 @@
 """
+Writer functions for different groups of a NeXus file.
 """
 import sys
 import h5py
 import numpy as np
 
-# from pathlib import Path
-
 from . import find_scan_axis, split_arrays, calculate_origin
 from .. import create_attributes, set_dependency, imgcif2mcstas
 
@@ -151,13 +150,13 @@ def write_NXsample(
         create_attributes(nxsample_ax, ("NX_class",), ("NXpositioner",))
         if ax == scan_axis:
             # If we're dealing with the scan axis
+            idx = goniometer["axes"].index(scan_axis)
             try:
                 for k in nxsfile["entry/data"].keys():
                     if nxsfile["entry/data"][k].attrs.get("depends_on"):
                         nxsample_ax[ax] = nxsfile[nxsfile["entry/data"][k].name]
                         nxtransformations[ax] = nxsfile[nxsfile["entry/data"][k].name]
             except KeyError:
-                idx = goniometer["axes"].index(scan_axis)
                 nxax = nxsample_ax.create_dataset(ax, data=scan_range)
                 _dep = set_dependency(
                     goniometer["depends"][idx], path="/entry/sample/transformations/"
@@ -189,13 +188,13 @@ def write_NXsample(
                 goniometer["depends"][idx], path="/entry/sample/transformations/"
             )
             create_attributes(
-                ax,
+                nxax,
                 ("depends_on", "transformation_type", "units", "vector"),
                 (
                     _dep,
                     goniometer["types"][idx],
                     goniometer["units"][idx],
-                    vectors[scan_axis],
+                    vectors[ax],
                 ),
             )
             nxtransformations[ax] = nxsfile[nxax.name]
@@ -259,7 +258,7 @@ def write_NXinstrument(
 
 
 # NXsource
-def write_NXsource(nxsfile: h5py.File, source):
+def write_NXsource(nxsfile: h5py.File, source: dict):
     """
     Write NXsource group in entry/source.
 
@@ -376,19 +375,24 @@ def write_NXdetector(
     # Create groups for detector_z and two_theta if present
     vectors = split_arrays(coord_frame, detector["axes"], detector["vectors"])
 
+    # FIXME this assumes only detector_z or two_theta as axes
     for ax in detector["axes"]:
+        idx = detector["axes"].index(ax)
         if ax == "det_z":
             grp_name = "detector_z"
+            _dep = set_dependency(
+                detector["depends"][idx],
+                "entry/instrument/detector/transformations/two_theta/",
+            )
         else:
             grp_name = ax
-        idx = detector["axes"].index(ax)
+            _dep = set_dependency(
+                detector["depends"][idx],
+                "entry/instrument/detector/transformations/detector_z/",
+            )
         nxgrp_ax = nxtransformations.create_group(grp_name)
         create_attributes(nxgrp_ax, ("NX_class",), ("NXpositioner",))
         nxdet_ax = nxgrp_ax.create_dataset(ax, data=detector["starts"][idx])
-        _dep = set_dependency(
-            detector["depends"][idx],
-            "entry/instrument/detector/transformations/" + grp_name,
-        )
         create_attributes(
             nxdet_ax,
             ("depends_on", "transformation_type", "units", "vector"),
@@ -396,7 +400,7 @@ def write_NXdetector(
                 _dep,
                 detector["types"][idx],
                 detector["units"][idx],
-                vectors[idx],
+                vectors[ax],
             ),
         )
 
@@ -511,11 +515,11 @@ def write_NXdetector_module(
             ),
             (
                 "/entry/instrument/detector/transformations/detector_z/det_z",
-                origin,
+                [0, 0, 0],  # origin,
                 "mm",
                 "translation",
                 "mm",
-                [1, 0, 0],
+                origin,  # [1, 0, 0],
             ),
         )
         # Correct dependency tree accordingly
